<?php
/**
  Plugin Name: Mollie addon for Restrict Content Pro
  Plugin URI: https://www.degrinthorst.nl/downloads/mollie-rcp-plugin
  Description: An addon which adds Mollie payments to Restrict Content Pro
  Version: 2.0.6
  Author: Sander de Wijs
  Author URI: https://www.degrinthorst.nl
  License: GPL2
 */

// Prevent this file from being called directly
if ( !function_exists( 'add_action' ) ) {
    echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
    exit;
}

// Make sure this plugin is loaded after RCP!
add_action( 'activated_plugin', 'rcp_mollie_load_first' );
function rcp_mollie_load_first()
{
    $path = str_replace( WP_PLUGIN_DIR . '/', '', __FILE__ );
    if ( $plugins = get_option( 'active_plugins' ) ) {
        if ( $key = array_search( $path, $plugins ) ) {
            array_splice( $plugins, $key, 1 );
            array_push( $plugins, $path );
            update_option( 'active_plugins', $plugins );
        }
    }
}

add_action('admin_menu', 'add_rcp_mollie_options_page');
add_action('admin_init', 'rcp_mollie_settings_init');
add_action('admin_enqueue_scripts', 'rcp_mollie_scripts_styles');
add_action('plugins_loaded', 'load_rcp_mollie_classes');

if (!defined('RCP_MOLLIE_PLUGIN_DIR')) {
    define('RCP_MOLLIE_PLUGIN_DIR', plugin_dir_path(__FILE__));
}

// RCP Mollie settings
require( 'inc/rcp-mollie-settings.php' );

// Function for loading RCP classes after plugins loaded
function load_rcp_mollie_classes() {
    //var_dump(function_exists('rcp_is_active'));wp_die();
    include(dirname(__FILE__) . '/inc/gateway/class-rcp-mollie-gateway.php');
    include(dirname(__FILE__) . '/inc/payment/class-rcp-mollie-payments.php');
}

/**
 * Store Mollie Payment methods in the database
 * to minimize API calls. Update payment methods only when RCP MOllie settings
 * are saved.
 *
 * @param $gateways
 * @since 2.0
 */
function rcp_load_mollie_methods($gateways)
{

    $options = get_option('rcp_mollie_settings');
    $mollie_gateways = array();
    $options['mollie_gateways'][] = $mollie_gateways;
    $methods = $gateways;

    foreach ($methods as $method) {
        $gateway = json_decode(json_encode($method->id), true);
        $label = json_decode(json_encode($method->description), true);
        $admin_label = json_decode(json_encode($method->description), true) . ' (Mollie)';
        $img = htmlspecialchars($method->image->normal);

        $mollie_gateways[$gateway] = array(
            'id'    => $gateway,
            'label' => $label,
            'admin_label' => $admin_label,
            'image' => $img,
            'class' => 'RCP_Payment_Gateway_Mollie'
        );
    }
    $options['mollie_gateways'] = $mollie_gateways;
    update_option('rcp_mollie_settings', $options);
}

add_action( 'wp_ajax_rcpMollieGatewayUpdate', 'rcpMollieGatewayUpdate' );
add_action( 'wp_ajax_nopriv_rcpMollieGatewayUpdate', 'rcpMollieGatewayUpdate' );

/**
 * Process Ajax call from the settings page. Update Mollie API keys, active gateways
 * and other settings and save them in the database.
 */
function rcpMollieGatewayUpdate() {
    $response = 0;
    $options = array();

    if(isset( $_POST['molliercpUpdateOptions_nonce']) && wp_verify_nonce( $_POST['molliercpUpdateOptions_nonce'], 'molliercpUpdateOptions_html' )) {
        if(isset($_POST['rcp_mollie_live_api_field'])) {
            $mollie_live_api = sanitize_text_field($_POST['rcp_mollie_live_api_field']);
        } else {
            $mollie_live_api = "";
        }
        $options[ 'rcp_mollie_live_api_field' ] = $mollie_live_api;

        if(isset($_POST['rcp_mollie_test_api_field'])) {
            $mollie_test_api = sanitize_text_field($_POST['rcp_mollie_test_api_field']);
        } else {
            $mollie_test_api = "";
        }
        $options['rcp_mollie_test_api_field'] = $mollie_test_api;

        if(isset($_POST['rcp_mollie_test_modus'])) {
            $rcp_mollie_test_mode = $_POST['rcp_mollie_test_modus'];
        } else {
            $rcp_mollie_test_mode = 0;
        }
        $options['rcp_mollie_test_modus'] = $rcp_mollie_test_mode;

        if(isset($_POST['rcp_mollie_remove_settings'])) {
            $rcp_mollie_remove_settings = $_POST['rcp_mollie_remove_settings'];
        } else {
            $rcp_mollie_remove_settings = 0;
        }
        $options['rcp_mollie_remove_settings'] = $rcp_mollie_remove_settings;

        update_option('rcp_mollie_settings', $options);
        $mollie_connect = mollieApiConnect();

        // Get enabled payment methods from Mollie
        try {
            $methods = $mollie_connect->methods->all();
        } catch (Mollie_API_Exception $e) {
            echo "API call failed: " . htmlspecialchars($e->getMessage());
        }
        if(!empty($methods)) {
            rcp_load_mollie_methods($methods);
            $response = 2;
        } else {
            $response = 0;
        }

        echo json_encode($response);
        wp_die();
    }

}

register_activation_hook(__FILE__, 'rcp_mollie_activate');

/**
 * On plugin activation add a columns in rcp_payments table to store the Mollie payment ID.
 */
function rcp_mollie_activate()
{
    global $wpdb;

    $db_prefix = $wpdb->base_prefix;
    $check_for_mollie_id_col = $wpdb->get_results(
        "
                SELECT 'mollie_id'
                FROM INFORMATION_SCHEMA.COLUMNS
                WHERE table_name = '" . $db_prefix . 'rcp_payments' . "'
                AND column_name = 'mollie_id'
                "
    );

    if (!$check_for_mollie_id_col) {
        $wpdb->query(
            "
        ALTER TABLE " . $db_prefix . 'rcp_payments' . "
        ADD mollie_id TINYTEXT NULL
        "
        );
    }
}

register_deactivation_hook(__FILE__, 'rcp_mollie_deactivate');

/**
 * On deactivation remove the mollie_id column and settings from the database.
 */
function rcp_mollie_deactivate()
{
    global $wpdb;
    $db_prefix = $wpdb->base_prefix;

    $options = get_option('rcp_mollie_settings');

    $check_for_mollie_id_col = $wpdb->get_results(
        "
                SELECT 'mollie_id'
                FROM INFORMATION_SCHEMA.COLUMNS
                WHERE table_name = '" . $db_prefix . 'rcp_payments' . "'
                AND column_name = 'mollie_id'
                "
    );

    if (!empty($check_for_mollie_id_col) && isset($options['rcp_mollie_remove_settings'])) {
        $wpdb->query(
            "
            ALTER TABLE " . $db_prefix . 'rcp_payments' . "
            DROP COLUMN mollie_id
            "
            );
        unregister_setting('rcp-mollie-settings-group', 'rcp_mollie_test_api_field', '');
    }
}
